.. _all-salt.returners:

=====================================
Full list of builtin returner modules
=====================================

.. currentmodule:: salt.returners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    carbon_return
    cassandra_return
    couchbase_return
    couchdb_return
    django_return
    elasticsearch_return
    etcd_return
    hipchat_return
    kafka_return
    local
    local_cache
    memcache_return
    mongo_future_return
    mongo_return
    multi_returner
    mysql
    odbc
    postgres
    postgres_local_cache
    redis_return
    sentry_return
    slack_returner
    sms_return
    smtp_return
    sqlite3_return
    syslog_return
    xmpp_return
